'use strict';

const fs = require('fs');
const path = require('path');
const co = require('co');
const debug = require('debug')('boat-cli:build');
const login = require('../../lib/login/index');
const build = require('../../command/build/index');
const getServer = require('../../lib/get-server');

// 获取 token
const token = login.readUserToken();
// 获取 app 信息
const app = getApp();
// 获取 server 信息
const server = getServer(process.argv);

debug('params', token, app);

co(function*() {
  yield build.run({
    token: token,
    appId: app.appId,
    server: server
  });
}).catch(e => {
  debug(e);
  console.error(e.message);
  process.exit(1);
})

// 获取 app 信息
function getApp() {
  try {
    let pkgContent = JSON.parse(fs.readFileSync(path.join(process.cwd(), 'package.json'), 'utf-8'));
    let app = pkgContent.boat;

    if(!(app && parseInt(app.appId))){
        throw Error('从 package.json 中获取应用信息出错');
    };

    app.appId = parseInt(app.appId);

    return app;
  }catch(e){
    debug(e);
    console.error('未获取到应用信息');
    process.exit(1);
  }
}