'use strict';

const path = require('path');
const {fork} = require('child_process')
const fs = require('fs');
const program = require('commander');
const co = require('co');
const debug = require('debug')('boat-cli:dev');
const args = process.argv.slice(3);
const cwd = process.cwd();
const {checkProject} = require('../../lib/project');

program
.option('-d, --debug', '取消启动 weex debug 服务器')
.option('-k, --skip', '跳过安装项目依赖(dependencies)后启动')
.option('-p, --port [port]', '设置启动端口号')
.option('-x, --disableDesktop', '取消调试桌面')
.parse(process.argv);

co(function*(){
  yield dev();
}).catch(e => {
  debug(e);
  console.error(e.message);
  process.exit(1);
})


function* dev(){
  let checkResult = checkProject();
  if(checkResult.success) {
    const ui = require('../../lib/ui');
    
    if(!program.skip) {
      const npm = require('../../lib/npm');

      console.log(ui.green('依赖更新中...'));
      npm.update()
      console.log(ui.green('依赖更新完毕'));
    }

    if(!program.debug) {
      const {devtool_server_port} = require('../../config');
      const {startDevtoolServer} = require('../../command/debug');

      yield startDevtoolServer(devtool_server_port);
    }



    console.log(ui.green('启动编译...'));    
    const start = require('../../command/start');
    
    let param = {}
    let port = parseInt(program.port, 10);
    if(!isNaN(port)){
      param = {
        port
      }
    }
    
    let customPage = program.args    
    param.customPage = customPage

    if(!program.disableDesktop) {
      setTimeout(()=>{    
        let desktop = require.resolve('../../command/lib/desktop/app.js')
        let ip = require('ip')
        let desktopChild = fork(desktop, [
          '--opts=' + JSON.stringify({
            cwd: cwd,
            customPage: customPage,
            port: param.port || 9999,
            ip: ip.address()
          })
        ])
      }, 8000)
    }
    
    start.startCompiler(param);
  }else {
    if(checkResult.code == checkProject.CHECK_ERROR_NOT_BOAT_APP) {
      const ui = require('../../lib/ui');      
      console.log(ui.yellow('当前仓库的 app 配置错误，请参考文档 http://xxxx.xx.xx 调整配置或创建本地项目'));

    }else if(checkResult.code == checkProject.CHECK_ERROR_EMPTY_DIR){
      const ui = require('../../lib/ui');
      let doInit = yield ui.confirm(('当前目录不存在项目, 是否初始化 app'));
      if(!doInit) {
        return;
      }
      const {initProjectFromServer} = require('../../command/init');
      yield initProjectFromServer();
    }else {
      const ui = require('../../lib/ui');        
      console.log(ui.yellow('您还没有在平台上创建 app ，请前往 http://amdp.alibaba.net/apps/ 创建 app 后重试'));
    }
  }
}





