'use strict';

const fs = require('fs')
const path = require('path');
const tar = require('tar-stream');
const glob = require("glob");
const zlib = require('zlib');
const log = require('./log');
const debug = require('debug')('boat-cli:build');

exports.pack = function* (cwd) {
  log.info('正在打包本地文件');

  const files = yield getPackFiles({
    where: cwd,
    patterns: '**/*',
    ignore: ['**/node_modules/**', '**/.git/**', 'build/**']
  });
  const stream = yield pack(cwd, files);
  return stream;
};

// 获取待打包文件列表
function* getPackFiles(options) {
  const where = options.where,
    ignore = options.ignore,
    patterns = options.patterns || '**/*';

  return new Promise(function (resolve, reject) {
    var tar_pack;
    glob(patterns, {
      cwd: where,
      dot: true,
      ignore: ignore
    }, function (err, matches) {
      if (err) {
        return reject(err);
      };

      if (!matches.length) {
        return reject(new Error('待打包文件夹下无文件'));
      };

      resolve(matches);
    });
  });
}

// 打包文件，获取 stream 流
function* pack(where, files) {
  if (!files.length) {
    throw Error('待打包文件夹下无文件');
  };

  const tar_pack = tar.pack();
  for (let file of files) {
    let filePath = path.join(where, file);
    let stat = fs.statSync(filePath);
    // 必须设置 mtime，否则每次生成的 gzip 包 md5 不一致
    if (stat.isDirectory()) {
      tar_pack.entry({
        name: file,
        mtime: new Date(stat.mtime),
        type: 'directory'
      });
    } else {
      tar_pack.entry({
        name: file,
        mtime: new Date(stat.mtime),
      }, fs.readFileSync(filePath))
    }
  };
  tar_pack.finalize();
  return tar_pack.pipe(zlib.createGzip());
};