const fs = require('fs')
const path = require('path')
const Koa = require('koa')
const Router = require('koa-router')
const bodyParser = require('koa-bodyparser')
const render = require('koa-ejs')
const serve = require('koa-static')
const yargsParser = require('yargs-parser')
const glob = require('glob')
const chalk = require('chalk')
const open = require('open')

const app = new Koa()
const router = new Router()
const argv = yargsParser(process.argv.slice(2))
const opts = JSON.parse(argv.opts)
const desktopPort = opts.port + 1;
const customPage = opts.customPage || []


render(app, {
  root: path.join(__dirname, 'view'),
  viewExt: 'html',
  layout: false,
  cache: false
})

function getPageData(dir){
  let files = glob.sync("src/pages/**/{*.vue,*.js}", {cwd: dir})
  let pageData = {}

  files.filter((file)=>{
    let pageName = file.match(/src\/pages\/([^/]+)\//)[1]

    if(customPage.length != 0) {
      return customPage.indexOf(pageName) != -1
    }else {
      return true
    }
    
  }).forEach((file)=>{
    let pageName = file.match(/src\/pages\/([^/]+)\//)[1]
    if(!pageData[pageName]) {
      pageData[pageName] = {}
      pageData[pageName]['mtime'] = -1
      pageData[pageName]['files'] = []
    }
  
    pageData[pageName]['files'].push(file)  
    pageData[pageName].mtime = Math.max(fs.statSync(file).mtime.getTime(), pageData[pageName].mtime)
  })
  
  return pageData
}



router.get('/', async (ctx, next) => {  
  let pageData = getPageData(opts.cwd);
  let renderData = [];

  for(let pageName in pageData) {
    renderData.push({
      href: `http://${opts.ip}:${opts.port}/${pageName}.html`,
      bundleHref: `http://${opts.ip}:${opts.port}/${pageName}.js`,
      name: pageName,
      mtime: pageData[pageName].mtime
    })
  }
  
  await ctx.render('index', {
    pageData: renderData,
    devtoolHref: `http://${opts.ip}:8088/`
  })
})

app.use(bodyParser())
   .use(router.routes())
   .use(serve(path.join(__dirname, 'static')))
   .use(router.allowedMethods())

app.listen(desktopPort, function(){
  console.log(chalk.yellow(`\ndesktop listen on http://${opts.ip}:${desktopPort}/`))
  open(`http://${opts.ip}:${desktopPort}/`)
})
