'use strict';

const path = require('path');
const fs = require('fs');
const walk = require('walk');
const appDirectory = fs.realpathSync(process.cwd());

function resolveApp(relativePath){
  return path.resolve(appDirectory, relativePath);
}

const nodePaths = (process.env.NODE_PATH || '')
  .split(process.platform === 'win32' ? ';' : ':')
  .filter(Boolean)
  .map(resolveApp);

const paths = {
  appBuild: resolveApp('build'),
  appPublic: resolveApp('public'),
  appHtml: resolveApp('public/index.html'),
  // appIndexJs: resolveApp('src/index.js'),
  appPackageJson: resolveApp('package.json'),
  appSrc: resolveApp('src'),
  appNodeModules: resolveApp('node_modules'),
  nodePaths: nodePaths
};

let entry = {};
let pageArr = [];

let walkResult = walk.walkSync(paths.appSrc, {
  listeners: {
    file: function(root, fileStats, next){
      if(/pages[\/\\][^\/\\]+$/.test(root)) {

        let filename = fileStats.name; 
        if('index.js' == filename) {
          let pagename = root.match(/pages[\/\\]([^\/\\]+)$/)[1];
          
          pageArr.push(pagename);
          entry[`${pagename}`] = [path.join(appDirectory, 'src/pages', pagename, 'index.js')];
        }
      }

    }
  }
});

paths.entry = entry;
paths.pageArr = pageArr;



module.exports = paths;