'use strict';

const CaseSensitivePathsPlugin = require('case-sensitive-paths-webpack-plugin');
const colors = require('chalk');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const RaxWebpackPlugin = require('rax-webpack-plugin');
const WatchMissingNodeModulesPlugin = require('watch-missing-node-modules-webpack-plugin');
const webpack = require('webpack');
const path = require('path');
const paths = require('./paths');
const babelConfig = require('./babel.config');

const publicPath = '/';
const publicUrl = '';

let baseConfig = {
  context: process.cwd(),
  target: 'web',
  entry: {},
  output: {
    path: paths.appBuild,
    pathinfo: true,
    filename: '[name].js',
    publicPath: publicPath
  },
  resolve: {
    extensions: ['.js', '.json', '.jsx']
  },
  plugins: [
    new RaxWebpackPlugin({
      target: 'bundle',
      externalBuiltinModules: false
    }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: JSON.stringify(process.env.NODE_ENV || 'development'),
        PUBLIC_URL: JSON.stringify(publicUrl)
      }
    }),
    new CaseSensitivePathsPlugin(),
    new WatchMissingNodeModulesPlugin(paths.appNodeModules),
    new webpack.ProgressPlugin(),
    new webpack.LoaderOptionsPlugin({
      options:{
        babel: babelConfig
      }
    })
  ],
  module: {
    loaders: [
      {
        test: /\.jsx?$/,
        exclude: /(node_modules|bower_components)/,
        loaders: [require.resolve('babel-loader')]
      },
      {
        test: /\.css$/,
        loader: require.resolve('stylesheet-loader')
      },
      {
        test: /\.json$/,
        loader: require.resolve('json-loader')
      },
      {
        test: /\.(png|jpe?g|gif)$/i,
        loader: require.resolve('image-source-loader')
      }
    ]
  }
}
paths.pageArr.forEach(function(pagename){
  baseConfig.plugins.push(new HtmlWebpackPlugin({
    filename: `${pagename}.html`,
    inject: true,
    template: paths.appHtml,
    chunks:[`${pagename}`]
  }))
})


module.exports = baseConfig;