var path = require('path')
const fs = require('fs');
var resolve = require('../utils').resolve
var walk = require('walk');
const appDirectory = fs.realpathSync(process.cwd());
const uniq = require('lodash.uniq');


let pageArr = [];
let entry = {
  web: {},
  native: {}
};

let customPage = process.env.BOAT_CUSTOMPAGE || []

let walkResult = walk.walkSync(path.join(appDirectory, 'src'), {
  listeners: {
    file: function(root, fileStats, next){
      if(/pages[\/\\][^\/\\]+$/.test(root)) {
        let filename = fileStats.name; 
        
        if(/^index.(web|native).js$/.test(filename)) {
          let type = RegExp.$1;
          let pagename = root.match(/pages[\/\\]([^\/\\]+)$/)[1];

          if(customPage.length != 0 && customPage.indexOf(pagename) == -1) {
            return
          }

          pageArr.push(pagename);

          let entryName = ''
          if(type == 'native') {
            entryName = pagename;
          }else if(type == 'web'){
            entryName = `${pagename}.${type}`
          }
          entry[type][entryName] = [path.join(appDirectory, 'src/pages', pagename, filename)];
        }
      }
    }
  }
});

pageArr = uniq(pageArr);

// console.log('entry');
// console.log(entry);

module.exports = {
  build: {
    env: require('./prod.env'),
    // entryPath: {
    //   web: resolve('src/web.entry.js'),
    //   native: resolve('src/native.entry.js')
    // },
    
    entry: entry,
    pageArr: pageArr,
    // index: resolve('public/index.html'),
    publicDistRoot: path.join(appDirectory, 'build'),
    publicRoot: appDirectory, //path.join(appDirectory, 'build'),
    publicPath: '/',
    appPublic: path.join(appDirectory, 'public'),
    appHtml: path.join(appDirectory, 'public', 'index.html'),
    productionSourceMap: true,
    
  },
  dev: {
    env: require('./dev.env'),
    clientPath: resolve('dev-client.js'),
    port: 8081,
    autoOpenBrowser: true,
    assetsSubDirectory: 'static',
    publicPath: '/',
    proxyTable: {},
    appPublic: path.join(appDirectory, 'public')
  }
}


