var path = require('path')
var webpack = require('webpack')
var merge = require('webpack-merge')
var CleanWebpackPlugin = require('clean-webpack-plugin')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const HtmlWebpackIncludeAssetsPlugin = require('html-webpack-include-assets-plugin')
var vueLoaderConfig = require('./vue-loader.config.js')
var config = require('./config');
const babelConfig = require('./babel.config');

var baseConfig = {
  context: process.cwd(),
  output: {
    path: config.build.publicDistRoot,
    publicPath: config.build.publicPath,
    pathinfo: true
  },
  resolve: {
    // 最后一个路径支撑 ide 中的情况
    modules: ['node_modules', path.join(__dirname, '../../../../node_modules'), path.join(__dirname, '../../../../../../node_modules')],
    extensions: ['.js', '.vue'],
    alias: {
      c: path.resolve(process.cwd(), 'src', 'components')
    }
  },
  resolveLoader: {
    modules: ['node_modules', path.join(__dirname, '../../../../node_modules'), path.join(__dirname, '../../../../../../node_modules')]
  },
  module: {
    rules: [{
      test: /\.js$/,
      loader: require.resolve('babel-loader'),
      exclude: /node_modules(?!\/.*(weex|ali).*)/,
      options: babelConfig
    }]
  },
  plugins: [
    
  ]
}

var webConfig = merge(baseConfig, {
  entry: config.build.entry.web,
  resolve: {
    modules: [path.join(__dirname, '../../../node_modules')]
  },
  resolveLoader: {
    modules: [path.join(__dirname, '../../../../node_modules')]
  },
  module: {
    rules: [{
      test: /\.vue$/,
      loader: require.resolve('vue-loader'),
      options: vueLoaderConfig
    }],
  },
  output: {
    filename: '[name].js'
  }
  //, contentBase: config.dev.appPublic,
  // watchContentBase: true,
})

var nativeConfig = merge(baseConfig, {
  entry: config.build.entry.native,
  module: {
    rules: [{
      test: /\.vue$/,
      loader: require.resolve('weex-loader'),
      options: vueLoaderConfig      
    }],
  },
  output: {
    filename: '[name].js'
  },
  plugins: [
    new webpack.BannerPlugin({
      banner: '// { "framework": "Vue" } \n',
      raw: true,
      exclude: 'Vue'
    }),
    new webpack.ProgressPlugin()
  ]
})

// console.log('config.build.appHtml', config.build.appHtml);
config.build.pageArr.forEach(function(pagename){
  // console.log('pagename', pagename);
  webConfig.plugins.push(new HtmlWebpackPlugin({
    filename: `${pagename}.html`,
    inject: true,
    template: config.build.appHtml,
    chunks: []
  }))
  webConfig.plugins.push(new HtmlWebpackIncludeAssetsPlugin({
    files: [`${pagename}.html`],
    assets: [`${pagename}.web.js`],
    append: true,
    publicPath: false
  }))
})

module.exports = [webConfig, nativeConfig]
