'use strict';

process.env.NODE_ENV = 'development';

process.on('unhandledRejection', err => {
  throw err;
});

const colors = require('chalk');
const WebpackDevServer = require('webpack-dev-server');
const createWebpackCompiler = require('./create-webpack-compiler');
const webpackConfigDev = require('../../lib/webpack-config/react/webpack.config.dev');
const webpackDevServerConfig = require('../../lib/webpack-config/react/webpackDevServer.config');
const options = require('./dev-utils/parse-options');
const paths = require('../../lib/webpack-config/react/paths');


function outputDevUrl(){
  let pageArr = paths.pageArr;

  console.log(colors.yellow('\n\n编译完成后，点击调试链接: '));  
  pageArr.forEach(function(pagename){
    let serverUrl = `${pagename}: ${options.protocol}//${options.host}:${options.port}/${pagename}.html`;
    console.log(colors.underline(serverUrl));  
  });
  console.log('\n');
}

/**
 * run webpack dev server
 * @param  {Number} port server port
 */
function start(port) {
  const compiler = createWebpackCompiler(webpackConfigDev);
  const server = new WebpackDevServer(compiler, webpackDevServerConfig)

  server.listen(port, err => {
    if(err){
      console.log(colors.red('[ERR]: Faild to webpack dev server'));
      console.error(err.message || err);
      process.exit(1);
    }


    outputDevUrl();
  });
}

start(options.port);

