'use strict';

process.env.NODE_ENV = 'development';

process.on('unhandledRejection', err => {
  throw err;
});

const address = require('address');
const ip = address.ip();
const colors = require('chalk');
const WebpackDevServer = require('webpack-dev-server');
const createWebpackCompiler = require('./create-webpack-compiler');
const webpackConfigDev = require('../../lib/webpack-config/vue/webpack.dev.config');
const webpackDevServerConfig = require('../../lib/webpack-config/vue/webpackDevServer.config');
const options = require('../../../lib/parse-options');

function start(port){
  const compiler = createWebpackCompiler(webpackConfigDev);
  const server = new WebpackDevServer(compiler, webpackDevServerConfig);

  server.listen(port, ip, err => {

    if(err){
      console.log(colors.red('[ERR]: Faild to webpack dev server'));
      console.error(err.message || err);
      process.exit(1);
    }
    
    outputDevUrl({port});
    
  })
}

function outputDevUrl(options){
  const {build:{pageArr}} = require('../../lib/webpack-config/vue/config/index');
  
  console.log(colors.yellow('\n\n编译完成后，点击调试链接: '));  
  pageArr.forEach(function(pagename){
    let serverUrl = colors.underline(`http://${ip}:${options.port}/${pagename}.html`);
    console.log(`${pagename}: ${serverUrl}`);
  });

  console.log(colors.yellow('\n对应页面 native 版 bundle 调试链接'));
  pageArr.forEach(function(pagename){
    let bundleUrl = colors.underline(`http://${ip}:${options.port}/${pagename}.js`);
    console.log(`${pagename}: ${bundleUrl}`);
  });

  console.log('\n');

}

start(options.port);
