'use strict';

const path = require('path');
const nconf = require('nconf');
const fs = require('fs-extra');
const homedir = require('./homedir')();

const configDir = path.join(homedir, '.boat_config');
const configFile = path.join(configDir, 'config');

exports.configDir = configDir;
exports.sshkeyDir = path.join(configDir, '.ssh');
exports.gitDir = path.join(configDir, 'git');

fs.ensureDirSync(exports.configDir);
fs.ensureDirSync(exports.sshkeyDir);
fs.ensureDirSync(exports.gitDir);

exports.home = homedir

nconf.argv()
     .env()
     .file({file: configFile});

exports.get = nconf.get.bind(nconf);
exports.set = nconf.set.bind(nconf);
exports.save = function(){
  return new Promise(function(resolve, reject){
    nconf.save(function(err){
      if(err){
        console.log(err);
        return reject(err);
      }
      resolve();
    })
  })
}

exports.env = process.env.BOAT_ENV || 'daily';// 开发期间先选为日常
exports.dsl = function(){
  let dsl = '';
  try {
    let pkg = JSON.parse(fs.readFileSync(path.join(process.cwd(), 'package.json'), 'utf-8'));
    dsl = pkg.boat.dsl;
  }catch(e){}

  return dsl;
}

exports.devtool_server_port = process.env.BOAT_DEVTOOL_SERVER_PORT || '8088';


