'use strict';
const got = require('got');
const co = require('co');
const config = require('../../config');
const env = config.env;
const ui = require('../ui');
const debug = require('debug')('boat-cli:login');

exports.readUserToken = function (){
  let localUserToken = config.get('user_token');
  return localUserToken;
}

let server = {
  local: 'http://127.0.0.1:6001',
  daily: 'http://boat.taobao.net'
}
server = server[env];


function loginByManul(){
  console.log(`自动登录失败, 请访问 ${server}/token/manual 复制 token，输入后登录`);
  return co(function*(){
    let user_token = yield ui.input('请粘贴 token: ');

    return user_token;
  })
}

exports.loginByManul = loginByManul;

exports.receiveToken = function (){
  const http = require('http');
  const url = require('url');
  const qs = require('querystring');

  return new Promise(function(resolve, reject){
    let timer;
    let waitingServer = http.createServer(function(req, res){
      let info = url.parse(req.url);
      console.log('req info');
      console.log(info);
      if(info.pathname == '/receive') {
        clearTimeout(timer);
        let queryObj = {};
        let query = qs.parse(info.query);
        res.setHeader('Access-Control-Allow-Origin', '*');
        res.end(JSON.stringify({
          success: true
        }));
        waitingServer.shutdown(function() {});
        resolve({user_token: query.user_token, user_nick: query.user_nick});
      }else {
        res.end(JSON.stringify({
          success: false
        }))
      }
    });
    waitingServer.listen();
    waitingServer = require('http-shutdown')(waitingServer);
    console.log('waitingServer port', waitingServer.address().port);

    // timer = setTimeout(function(){
    //   waitingServer.close();
    //   resolve(loginByManul());
    // }, 1000 * 5);
    
    // TODO: 环境区分
    let loginPage = `${server}/sdk/login?callbackUrl=http://127.0.0.1:${waitingServer.address().port}/receive` //`http://localhost:6677/token?_p=${waitingServer.address().port}`;
    debug('login url', loginPage);
    require('open')(loginPage, function(err){
      if(err) {
        waitingServer.shutdown(function() {});
        resolve(loginByManul());
      }
    });
  });
}

/*
exports.checkUserToken = function (user_token){
  return got('http://localhost:6677/token/check', {
    query:{
      user_token: user_token
    },
    timeout: 5000
  }).then(function(res){
    console.log('got res');
    console.log(res.body);
    return res.success;
  }).catch(function(err){
    console.log(err);
    return false;
  });
}
*/

exports.login = function* (server){
  let localUserToken = exports.readUserToken();
  let result = '';
  if(localUserToken) {
    // let checkResult = yield exports.checkUserToken(localUserToken);
    // if(checkResult) {
    //   return localUserToken;
    // }
    result = localUserToken;
  }else {
    let {user_token, user_nick} = yield exports.receiveToken(server);
    console.log('receive_token', user_token);
    config.set('user_token', user_token);
    config.set('user_nick', user_nick);
    yield config.save(); 
    result = user_token; 
  }

  return result
}


