'use strict';

const path = require('path')
const chalk = require('chalk')
const {sshkeyDir, home} = require('../../config/index')
// const keygen = require('ssh-keygen')
const keygen = require('sshkeygen')
const fs = require('fs-extra')
const sshKeyLocation = path.join(sshkeyDir, 'boat_user_rsa')
const sshDir = path.join(home, '.ssh')
const sshConfig = path.join(sshDir, 'config')


function getPubKey(){
  if(fs.existsSync(sshKeyLocation)) {
    let configContent = fs.readFileSync(sshConfig, 'utf-8')
    if(configContent.match(/boat_user_rsa(\w+)/)) {
      configContent = configContent.replace(/boat_user_rsa(\w+)/, `boat_user_rsa`)
      fs.writeFileSync(sshConfig, configContent)
    }
    return Promise.resolve(fs.readFileSync(sshKeyLocation + '.pub').toString());
  }else {
    return generateKey()
  }
}

function generateKey(){
  return new Promise(function(resolve, reject){
    console.log(chalk.green('自动生成 sshkey 中..'))

    keygen({
      location: sshKeyLocation,
      comment: 'boat',
      read: true    
    }, function(err, out){
      if(err) {
        console.log(chalk.red('生成错误.'))
        console.log(err.message);
        console.log(err.stack)
        return reject(err);
      }
      
      console.log(chalk.green(`sshkey 生成完成: ${sshKeyLocation}`))
      configKey()
      resolve(out.pubKey)
    })
  });
}

function configKey(){
  console.log(chalk.green('配置 sshkey 中..'))
  
  fs.ensureDirSync(sshDir)
  fs.ensureFileSync(sshConfig)

  let content = fs.readFileSync(sshConfig, 'utf-8');
  if(content.indexOf('Host aliyun_code code.aliyun.com') == -1) {
    content += `
    Host aliyun_code code.aliyun.com
    Hostname code.aliyun.com
    IdentityFile ${sshKeyLocation}
    StrictHostKeyChecking no`

    fs.writeFileSync(sshConfig, content)
  }else if(content.match(/boat_user_rsa(\w+)/)) {
    content = content.replace(/boat_user_rsa(\w+)/, `boat_user_rsa`)
    fs.writeFileSync(sshConfig, content)
  }

  console.log(chalk.green('sshkey 配置完成'))
}


exports.getPubKey = getPubKey
exports.generateKey = generateKey
exports.configKey = configKey
exports.sshKeyLocation = sshKeyLocation
